# apns_sdk_py

Python SDK for APNs API

[Pypi](https://pypi.org/project/apns-sdk-py)

## WARNING 警告

This Project is sunset, use [QiYuAPI](https://github.com/QiYuTechDev/qiyu-api) instead (all function have merged into)
